pub enum Term {
Atom(AtomId),
Var(VarId),
Integer(i64),
Float(f64),
Compound {
functor: AtomId,
args: Vec<Term>,
},
List {
head: Box<Term>,
tail: Box<Term>,
},
}Expand description
Prolog term representation.
Variants
Implementations
Sourceimpl Term
impl Term
Sourcepub fn functor_arity(&self) -> Option<(AtomId, usize)>
pub fn functor_arity(&self) -> Option<(AtomId, usize)>
Extract functor AtomId and arity for a term used as a goal/head.
- Atom: (atom_id, 0)
- Compound: (functor, len(args))
- Others: None
Sourcepub fn first_arg_key(&self) -> Option<FirstArgKey>
pub fn first_arg_key(&self) -> Option<FirstArgKey>
Extract the first-argument indexing key from a term used as a clause head.